function [buttpol]=buttpol(n,wc);
% buttpol
% buttpol(n,wc) calculates the poles for
% an 'n'th order Butterworth filter with
% angular 3dB cut-off frequency 'wc'.
% Conjugate poles are given separately as
% individual elements in the vector in
% consequtive order.
% If odd order the real pole is given as the
% last element in the vector.
% Ref:
% M.E. Van Valkenburg, "Analog Filter Design
% Holt-Saunders International Editions, 1982.

% 1997-03-10 Written by Lars Sundstrom,
% Dept of Appl Electronics, Lund University
% Copyright (c) 1997. All rights reserved
%
% 1998-01-26 - changed explaining text above


deltafi=pi/n;

% if even order
if floor(n/2)==n/2
   for k=1:n/2,
      p(2*k-1,1)=-wc*exp(i*(-deltafi/2+k*deltafi));
      p(2*k,1)=conj(p(2*k-1,1));
   end
else
% odd order
   for k=1:floor(n/2),
      p(2*k-1,1)=-wc*exp(i*(k*deltafi));
      p(2*k,1)=conj(p(2*k-1,1));  
   end
   p(n,1)=-wc;
end

buttpol=p;