function [chebpol]=chebpol(n,wc,rippledb);
% chebpol
% chebpol(n,wc,rippledb) calculates the poles
% for an 'n'th order Chebyshev filter with
% angular cut-off frequency wc and 'rippledb' dB
% of ripple. Note: at w=wc A(w)=-ripple dB,
% not 3dB as is the case for Butterworth
% filters (see buttpol.m).
% Conjugate poles are given separately as
% individual elements in the vector
% in consequtive order.
% If odd order the real pole is given as the
% last element in the vector.
% Ref:
% M.E. Van Valkenburg, "Analog Filter Design
% Holt-Saunders International Editions, 1982.

% 1997-03-10 Written by Lars Sundstrom,
% Dept of Appl Electronics, Lund University
% Copyright (c) 1997. All rights reserved
%
% 1998-01-26 - changed explaining text above


epsil=sqrt(10^(rippledb/10)-1);

a=asinh(1/epsil)/n;

p=buttpol(n,wc);

for k=1:n,
   p(k,1)=cos(angle(p(k,1)))*sinh(a)+i*sin(angle(p(k,1)))*cosh(a);
end

chebpol=p;