function [drawam]=drawam(startangle,stopangle,rstart,rstop,linewidth,amcolor,arhspec);
% drawam
% drawam(startangle,stopangle,rstart,rstop,linewidth,amcolor,arhspec);
% Draws lines, arcs and arrow heads for measuring an angle in a Smith chart
%
% Parameters:
% startangle - (in degrees) from this angle an arc is drawn counterclockwise
%              to stoppoangle
% stopangle - see above
% rstart - start of radial line - zero corresponds to the origin
% rstop - stop of radial line. Unity equals the Smith chart
%         The radial line is actually extended somewhat to cater for the
%         width of the arrow head.
%
% Optional:
% linewidth - in 1/72 inch (points)
% amcolor - [R,G,B]
% arhspec - row matrix [baseangle,tipangle,len]
%      baseangle - in degrees
%      tipangle - in degrees
%      len - length of arrow head (assumes a quadratic space)
%  ex. [70,16,1]
% 
% drawam returns a handle to arc drawn.


% 1996-12-23 Written by Lars Sundstrom,
% Dept of Appl Electronics, Lund University
% Copyright (c) 1996. All rights reserved.


% Global variables for parameters that are not specified
global daelibinitialized
global daearhspec
global daelinewidth
global daelinecolor

% Define global variables if necessary
if isempty(daelibinitialized),
	initdae;
end

% Set undefined parameters 
if nargin==4,
	arhspec=daearhspec;
	linewidth=daelinewidth;
	amcolor=daelinecolor;
else
	if nargin<7 arhspec=daearhspec; end
	if nargin<6 amcolor=daelinecolor; end
end


% Get measures for the arrow head
baseangle=pi*arhspec(1,1)/180;
tipangle=pi*arhspec(1,2)/180;
len=arhspec(1,3);
arhextent=len*sin(tipangle/2);

% just some measures to avoid that the arc runs into and
% destroys the tip of the arrow heads
if baseangle<pi/2,
	arcbackoff=len*(cos(tipangle/2)-sin(tipangle/2)*cos(baseangle));
else
	arcbackoff=len*cos(tipangle/2);
end
arcbackoffangle=180*arcbackoff/(rstop*pi);


% Draw radial lines
plotc([p2c(rstart,startangle);p2c(rstop+arhextent,startangle)],linewidth,'-',amcolor);
plotc([p2c(rstart,stopangle);p2c(rstop+arhextent,stopangle)],linewidth,'-',amcolor);

% Draw arc with some angular backoff not to destroy the tips
h=drawarc([0,rstop,startangle+arcbackoffangle,stopangle-arcbackoffangle],linewidth,'-',amcolor);

% Draw arrow heads
drawarhc(makearc([0,rstop,startangle,stopangle]),'be',arhspec,amcolor);

% Return handle to the arc drawn
drawam=h;

% end of drawam.m
