function [drawarc]=drawarc(arcspec,linewidth,linestyle,linecolor,markersize);
% drawarc
% drawarc(arcspec,linewidth,linestyle,linecolor,markersize)
% Draws one or several arcs in the current graph
%
% Parameters (column vector in case of multiple arcs):
% arcspec - [center,radius,startangle,stopangle]
%      center - center of circle (complex number)
%      radius - radius of circle
%      startangle - startangle (deg)
%      stopangle - stopangle (deg)
%
% Optional:
% linewidth - in 1/72 inch (points)
% linestyle - MATLAB parameter Ex. '-', '-.' etc
% linecolor - [R,G,B]
% markersize - in 1/72 inch (points)
% 
% drawarc returns a handle to the objects drawn. In case of
% multiple arcs a vertical vector is returned containing the
% handles.


% 1996-12-18 Written by Lars Sundstrom,
% Dept of Appl Electronics, Lund University
% Copyright (c) 1996. All rights reserved.


% Global variables for parameters that are not specified
global daelibinitialized
global daecircleresolution
global daelinewidth
global daelinestyle
global daelinecolor
global daemarkersize

% Define global variables if necessary
if isempty(daelibinitialized),
	initdae;
end

% Set undefined parameters 
if nargin==1,
	linecolor=daelinecolor;
	linestyle=daelinestyle;
	linewidth=daelinewidth;
	markersize=daemarkersize;
else
	if nargin<5 markersize=daemarkersize; end
	if nargin<4 linecolor=daelinecolor; end
	if nargin<3 linestyle=daelinestyle; end
end

% Number of arcs
c=size(arcspec);
c=c(1,1);

% storage for handles
h=zeros(c,1);

if c==1
	d=makearc(arcspec);
	h(1,1)=plotc(d,linewidth,linestyle,linecolor,markersize);
else
	cc=size(linewidth);
	if cc(1,1)==1, linewidth=ones(c,1)*linewidth; end

	cc=size(linestyle);
	if cc(1,1)==1, linestyle=setstr(ones(c,1)*linestyle); end
	
	cc=size(linecolor);
	if cc(1,1)==1, linecolor=ones(c,1)*linecolor; end

	cc=size(markersize);
	if cc(1,1)==1, markersize=ones(c,1)*markersize; end
	
	for k=1:c,
		d=makearc(arcspec(k,:));
		h(k,1)=plotc(d,linewidth(k,1),linestyle(k,:),linecolor(k,:),markersize(k,1));
	end
end

drawarc=h;

