function [drawarw]=drawarw(tippos,aangle,tlen,arhspec,linewidth,linestyle,arwcolor);
% drawarw
% drawarw(tippos,aangle,tlen,arhspec,linewidth,linestyle,arwcolor);
% Draws one or several arrows, ie, arrow head plus tail
%
% Parameters (column vector in case of multiple arrows):
% tippos - tip position given as complex number
% aangle - angle of arrow head in degrees - zero degrees == --->
%
% Optional:
% tlen - length of tail
% arhspec - row matrix [baseangle,tipangle,len]
%      baseangle - in degrees
%      tipangle - in degrees
%      len - length of arrow head (assumes a quadratic space)
%  ex. [70,16,1]
% linewidth - in 1/72 inch (points)
% linestyle - MATLAB parameter Ex. '-', '-.' etc
% arwcolor - [R,G,B]
% 
% drawarw returns a handle to the objects drawn in a row matrix with
% the arrow head in the first position and the tail in the second position.
% In case of multiple arcs a vertical vector is returned containing the
% handles.


% 1996-12-20 Written by Lars Sundstrom,
% Dept of Appl Electronics, Lund University
% Copyright (c) 1996. All rights reserved.


% Global variables for parameters that are not specified
global daelibinitialized
global daearhspec
global daefillcolor
global daelinewidth
global daelinestyle
global daelinecolor
global daearwlength

% Define global variables if necessary
if isempty(daelibinitialized),
	initdae;
end

% Set undefined parameters 
if nargin==2,
	arhspec=daearhspec;
	linewidth=daelinewidth;
	linestyle=daelinestyle;
	arwcolor=daefillcolor;
	tlen=daearwlength;
else
	if nargin<7 arwcolor=daefillcolor; end
	if nargin<6 linestyle=daelinestyle; end
	if nargin<5 linewidth=daelinewidth; end
	if nargin<4 tlen=daearwlength; end
end

% Number of arrow heads
c=length(tippos);

% storage for handles
h=zeros(c,2);


if c==1,
	baseangle=pi*arhspec(1,1)/180;
	tipangle=pi*arhspec(1,2)/180;
	len=arhspec(1,3);
	
	% just some measures to avoid that the tail runs into and
	% destroy the tip
	if baseangle<pi/2,
		tailbackoff=len*(cos(tipangle/2)-sin(tipangle/2)*cos(baseangle));
	else
		tailbackoff=len*cos(tipangle/2);
	end
	
	h(1,2)=plotc([tippos-p2c(tailbackoff,aangle);tippos-p2c(tlen,aangle)],...
		linewidth,linestyle,arwcolor);
	h(1,1)=drawarh(tippos,aangle,arhspec,arwcolor);
	
else
	cc=size(linewidth);
	if cc(1,1)==1, linewidth=ones(c,1)*linewidth; end

	cc=size(linestyle);
	if cc(1,1)==1, linestyle=setstr(ones(c,1)*linestyle); end
	
	cc=size(arwcolor);
	if cc(1,1)==1, arwcolor=ones(c,1)*arwcolor; end

	cc=size(arhspec);
	if cc(1,1)==1, arhspec=ones(c,1)*arhspec; end

	cc=size(tlen);
	if cc(1,1)==1, tlen=ones(c,1)*tlen; end

	for k=1:c,
		baseangle=pi*arhspec(k,1)/180;
		tipangle=pi*arhspec(k,2)/180;
		len=arhspec(k,3);
	
		% just some measures to avoid that the tail runs into and
		% destroy the tip
		if baseangle<pi/2,
			tailbackoff=len*(cos(tipangle/2)-sin(tipangle/2)*cos(baseangle));
		else
			tailbackoff=len*cos(tipangle/2);
		end
		
		h(k,2)=plotc([tippos(k,1)-p2c(tailbackoff,aangle(k,1));...
			tippos(k,1)-p2c(tlen(k,1),aangle(k,1))],...
			linewidth(k,1),linestyle(k,:),arwcolor(k,:));

		h(k,1)=drawarh(tippos(k,1),aangle(k,1),arhspec(k,:),arwcolor(k,:));
	end
end

drawarw=h;

