function [drawdot]=drawdot(pos,diameter,dotcolor);
% drawdot
% drawdot(pos,diameter,dotcolor);
% Draws one or several dots
%
% Parameters (column vector in case of multiple arrows):
% pos - center of dot given as complex number
%
% Optional:
% diameter - diameter of dot
% dotcolor - [R,G,B]
% 
% drawdot returns a handle to the objects drawn. In case of
% multiple dots a vertical vector is returned containing the
% handles.


% 1996-12-18 Written by Lars Sundstrom,
% Dept of Appl Electronics, Lund University
% Copyright (c) 1996. All rights reserved.


% Global variables for parameters that are not specified
global daelibinitialized
global daedotdiameter
global daefillcolor
global daecircleresolution
global daepscollectactive

% Define global variables if necessary
if isempty(daelibinitialized),
	initdae;
end

% Set undefined parameters 
if nargin==1,
	diameter=daedotdiameter;
	dotcolor=daefillcolor;
else
	if nargin<3 dotcolor=daefillcolor; end
end

% Number of dots
c=length(pos);

% storage for handles
h=zeros(c,1);

if c==1,
	d=makeci([pos,diameter/2],daecircleresolution/4);
	h(1,1)=patch(real(d),imag(d),dotcolor);
	set(h(1,1),'Linewidth',0.001,'EdgeColor',get(h(1,1),'facecolor'));
        if daepscollectactive==1
           pspatch(real(d),imag(d),dotcolor);
        end

else
	cc=size(diameter);
	if cc(1,1)==1,
		diameter=ones(c,1)*diameter;
	end

	cc=size(dotcolor);
	if cc(1,1)==1,
		dotcolor=ones(c,1)*dotcolor;
	end
	
	for k=1:c,
		d=makeci([pos(k,1),diameter(k,1)/2],daecircleresolution/4);
		h(k,1)=patch(real(d),imag(d),dotcolor(k,:));
		set(h(k,1),'Linewidth',0.001,'EdgeColor',get(h(k,1),'facecolor'));
                if daepscollectactive==1
                   pspatch(real(d),imag(d),dotcolor(k,:));
                end
	end
end

drawdot=h;

