function [drawrad]=drawrad(aangle,rstart,rstop,linewidth,linestyle,linecolor);
% drawrad
% drawrad(aangle,rstart,rstop,linewidth,linestyle,linecolor)
% Draws one radial line according to parameters
%
% Parameters:
% aangle - (in degrees) angle of radial line
% rstart - start of radial line - zero corresponds to the origin
% rstop - stop of radial line. Unity equals the Smith chart.
%
% Optional:
% linewidth - in 1/72 inch (points)
% linestyle - MATLAB parameter Ex. '-', '-.' etc
% linecolor - [R,G,B]
% 
% drawrad returns a handle to the line drawn.


% 1996-12-23 Written by Lars Sundstrom,
% Dept of Appl Electronics, Lund University
% Copyright (c) 1996. All rights reserved.


% Global variables for parameters that are not specified
global daelibinitialized
global daelinewidth
global daelinestyle
global daelinecolor

% Define global variables if necessary
if isempty(daelibinitialized),
	initdae;
end

% Set undefined parameters 
if nargin==3,
	linecolor=daelinecolor;
	linestyle=daelinestyle;
	linewidth=daelinewidth;
else
	if nargin<6 linecolor=daelinecolor; end
	if nargin<5 linestyle=daelinestyle; end
end

h=plotc([p2c(rstart,aangle);p2c(rstop,aangle)],linewidth,linestyle,linecolor);


% Return handle to the line drawn
drawam=h;

% end of drawam.m
