function [drawxci]=drawxci(x,linewidth,linestyle,linecolor,markersize);
% drawxci
% drawxci(x,linewidth,linestyle,linecolor,markersize)
% draws any number of constant-x(reactance) circles
% in the current graph. If multiple circles are to be drawn the
% x-values should appear in a vertical vector: [x1;x2;x3...].
% Optional:
% linewidth - in 1/72 inch
% linestyle - MATLAB parameter Ex. '-', '-.' etc
% linecolor - [R,G,B]
% markersize - in 1/72 inch (points)
% Examples:
% drawxci(0.5,1,-0.5,1)
% drawxci([0.5,1,-0.5,1]',2,'-.',[1,1,0],6)
% drawxci returns a handle to the line objects drawn. In case of
% multiple lines a vertical vector is returned containing the
% handles.

% 1994-12-01 Written by Lars Sundstrom,
% Dept of Appl Electronics, Lund University
% Copyright (c) 1996. All rights reserved.
% 1996-10-18 added linewidth and linecolor parameters
% 1996-12-19 renamed and support for dae variables and markersize


% Global variables for parameters that are not specified
global daelibinitialized
global daecircleresolution
global daelinewidth
global daelinestyle
global daelinecolor
global daemarkersize

% Define global variables if necessary
if isempty(daelibinitialized),
	initdae;
end

% Set undefined parameters 
if nargin==1,
	linecolor=daelinecolor;
	linestyle=daelinestyle;
	linewidth=daelinewidth;
   markersize=daemarkersize;
else
	if nargin<5 markersize=daemarkersize; end
	if nargin<4 linecolor=daelinecolor; end
   if nargin<3 linestyle=daelinestyle; end
end

c=size(x);
c=c(1,1);

% storage for handles
h=zeros(c,1);

if c==1,
	h(1,1)=drawxarc(x,0,1e6,linewidth,linestyle,linecolor,markersize);
else

	cc=size(linewidth);
	if cc(1,1)==1, linewidth=ones(c,1)*linewidth; end

	cc=size(linestyle);
   if cc(1,1)==1, linestyle=setstr(ones(c,1)*linestyle); end
	
	cc=size(linecolor);
	if cc(1,1)==1, linecolor=ones(c,1)*linecolor; end

	cc=size(markersize);
	if cc(1,1)==1, markersize=ones(c,1)*markersize; end

	for k=1:c,
		h(k,1)=drawxarc(x(k,1),0,1e6,linewidth(k,1),linestyle(k,:),linecolor(k,:),markersize(k,:));
	end
end

drawxci=h;
