function [makeci]=makeci(circlespec,n);
% makeci
% makeci(circlespec,n)
% Creates a column of points (complex values) for one circle.
% In case of column vector input, multiple columns are generated.
%
% Parameters (column vector in case of multiple arcs):
% circlespec - [center,radius]
%
% or       [center1,radius1;center2,radius2;... ]
%
%      center - center of circle (complex number)
%      radius - radius of circle
%
% Optional:
% n - number of line segments, uses daecircleresolution (default variable)
%     to calculate n if n is not specified.
%

% 1996-12-20 Written by Lars Sundstrom,
% Dept of Appl Electronics, Lund University
% Copyright (c) 1996. All rights reserved.
%
% 1998-05-21 - added support for column vector of
%              center and radius so that several
%              arcs can be created in one call.


% Global variables
global daelibinitialized
global daecircleresolution

% Define global variables if necessary
if isempty(daelibinitialized),
	initdae;
end

if nargin==1,
	% Number of line segments for a circle
	n=daecircleresolution;
end

makeci=makearc([circlespec(:,1),circlespec(:,2),0,0],n);