function [makerarc]=makerarc(r,xstart,xstop,n);
% makerarc
% makerarc(r,xstart,xstop,n)
% Creates a column of points (complex values) for one resistance arc
% In case of column vector input multiple columns are generated.
%
% Parameters (scalar or column vectors):
% r - normalized resistance
% xstart - start reactance (drawrarc always draws counterclockwise)
% xstop - stop reactance
%
% Optional:
% n - number of line segments, uses daecircleresolution to
%     calculate n if n is not specified.

% 1996-12-20 Written by Lars Sundstrom,
% Dept of Appl Electronics, Lund University
% Copyright (c) 1996. All rights reserved.
%

% 1998-05-21 - added support for column vector of
%              r,xstart and xstop so that several
%              arcs can be created in one call.


% Global variables
global daelibinitialized
global daecircleresolution

% Define global variables if necessary
if isempty(daelibinitialized),
	initdae;
end

colcount=length(r);

swapped=zeros(1,colcount);

for k=1:colcount
if xstart(k)<xstop(k),
	tmp=xstart(k);
	xstart(k)=xstop(k);
	xstop(k)=tmp;
	swapped(k)=1;
end
end

center=r./(r+1);
radius=1./(r+1);
startangle=180*angle(nz2g(r+i*xstart)-center)/pi;
stopangle=180*angle(nz2g(r+i*xstop)-center)/pi;

if nargin==3,
	h=makearc([center,radius,startangle,stopangle]);
else
	h=makearc([center,radius,startangle,stopangle],n);
end

% Ensure that the order of points corresponds to the direction given
% by xstart, xstop
for k=1:colcount,
	if swapped(k)==1,
		h(:,k)=flipud(h(:,k));
	end
end

makerarc=h;
