% Functions for Simple Network Design and Analysis
%
% * help <function name> for more information.
%
% These routines are used for calculating the reflection coefficient
% for a network consisting of resistances, capacitors, inductances and
% transmission lines. All routines require a refl. coeff. as input.
% The output is also a refl. coeff. To be able to use all routines the
% freq. must be specified. Actually all routines accept a matrix having
% refl. coeff. in the first column and corresponding frequency in the
% second column, ie: gamma=[gamma1, f1; gamma2, f2; ....]
% This makes it possible to analyze a network for several frequencies 
% simultaneously. For obvious reasons the frequency must be specified
% for the capacitor/inductor routines.
%
%  parc    - Calculates refl. coeff. for a given refl. coeff. in
%            parallel with a capacitance.
%  parg    - Calculates refl. coeff. for a given refl. coeff. in
%            parallel with another refl. coeff.
%  parl    - Calculates refl. coeff. for a given refl. coeff. in
%            parallel with an inductance.
%  parr    - Calculates refl. coeff. for a given refl. coeff. in
%            parallel with a resistance.
%  serc    - Calculates refl. coeff. for a given refl. coeff. in
%            series with a capacitance.
%  serl    - Calculates refl. coeff. for a given refl. coeff. in
%            series with an inductance.
%  serr    - Calculates refl. coeff. for a given refl. coeff. in
%            series with a resistance.
%  serline - Calculates refl. coeff. for a given refl. coeff. in
%            series with a lossless transmission line.

% 1997-10-25 Written by Lars Sundstrom,
% Dept of Appl Electronics, Lund University
% Copyright (c) 1997. All rights reserved.
