function [serline]=serline(gammaL,elecLength,f);
% serline
% serline(gammaL,elecLength,f) calculates the refl. coeff. for
% gammaL in series with a lossless transmission line.
% gammaL     - refl. coeff. for load impedance and corresponding
%              frequency (optional).
%              Format: [gammaL1,f1;gammaL2,f1;gammaL3,f3...].
% elecLength - electrical length (at f - see below) of the
%              transmission line.
% f          - The frequency for which elecLength is given.
%
% Note that the characteristic impedance for the transmission line
% is assumed to be the same as the normalization impedance for
% gammaL. If this is not the case, gammaL should be renormalized
% using the "renorm" function to the new characteristic impedance.

% 1996-12-19 Written by Lars Sundstrom,
% Dept of Appl Electronics, Lund University
% Copyright (c) 1996. All rights reserved.

if size(gammaL,2)==1,
	serline(:,1)=gammaL(:,1).*exp(-i.*4.*pi.*elecLength);
else
	serline=gammaL; 
	serline(:,1)=gammaL(:,1).*exp(-i.*4.*pi.*elecLength.*gammaL(:,2)./f);
end;
