function [writespar]=writespar(s,filename,comment1,comment2,comment3,comment4);
% writespar
% writespar(s,filename,comment1,...) exports S parameters to a file

% in Touchstone-format. "s" is assumed to be a 5 column matrix with the

% following row format: [s11 s21 s12 s22 frequency] wherer sij are complex

% quantities and the frequency is given in MHz.

% comment1, 2, 3 and 4 are optional and if present will be inserted in the

% Beginning of the file as comments:
% File Format, example:
%! <comment1>

%! <comment2>
%! <comment3>

%! <comment4>
%! 
%#  MHz  S  MA  R  50
%! Freq     S11  H11       S21  H21       S12  H12       S22  H22
%   40     .649 -58.6   26.551 150.9    .0240  65.7     .876 -28.6
%  100     .703 -110.   18.267 125.8    .0400  45.4     .624 -55.5
%  200     .734 -144.   10.958 105.7    .0490  33.0     .404 -77.6
%  300     .740 -160.    7.558  95.8    .0530  30.5     .315 -89.9
%


% 1999 Written by Lars Sundstrom,
% Dept of Appl Electronics, Lund University
% Copyright (c) 1999. All rights reserved.

%


% Create and open file
fid=fopen(filename,'w+');





% Design a new matrix with the correct format to be flushed to a file

d=size(s);
sf=zeros(d(1,1),9);

sf(:,1)=s(:,5);

% S11

sf(:,2)=abs(s(:,1));

sf(:,3)=angle(s(:,1))*180/pi;

% S21

sf(:,4)=abs(s(:,2));

sf(:,5)=angle(s(:,2))*180/pi;

% S12

sf(:,6)=abs(s(:,3));

sf(:,7)=angle(s(:,3))*180/pi;

% S22

sf(:,8)=abs(s(:,4));

sf(:,9)=angle(s(:,4))*180/pi;



if nargin>2

   fprintf(fid,'%s%s\n','! ',comment1);

end


if nargin>3

   fprintf(fid,'%s%s\n','! ',comment2);

end


if nargin>4

   fprintf(fid,'%s%s\n','! ',comment3);

end


if nargin>5

   fprintf(fid,'%s%s\n','! ',comment4);

end


fprintf(fid,'%s\n','!');
fprintf(fid,'%s\n','#  MHz  S  MA  R  5');
fprintf(fid,'%s\n','! Freq  S11  H11  S21  H21  S12  H12  S22  H22');
fprintf(fid,'%f %7.3f %7.1f %7.3f %7.1f %7.3f %7.1f %7.3f %7.1f\n',sf');

fclose(fid);

